@@ -10,11 +10,7 @@ import           Distribution.Pretty (prettyShow)
 import           Distribution.Version (mkVersion)
 import qualified Distribution.License as Cabal
 import qualified Distribution.SPDX.License as SPDX
-#if MIN_VERSION_Cabal(3,0,0)
 import           Distribution.Parsec (eitherParsec)
-#else
-import           Distribution.Parsec.Class (eitherParsec)
-#endif
 
 import qualified Data.License.Infer as Infer
 
