@@ -36,13 +36,8 @@ import           Text.PrettyPrint (renderStyle, Style(..), Mode(..))
 import           Distribution.Version (VersionRangeF(..))
 import qualified Distribution.Version as D
 
-#if MIN_VERSION_Cabal(3,0,0)
 import qualified Distribution.Parsec as D
 import qualified Distribution.Pretty as D
-#else
-import qualified Distribution.Parsec.Class as D
-import qualified Distribution.Text as D
-#endif
 
 import           Data.Aeson.Config.FromValue
 
@@ -156,11 +151,7 @@ versionConstraintFromCabal :: D.VersionRange -> VersionConstraint
 versionConstraintFromCabal range
   | D.isAnyVersion range = AnyVersion
   | otherwise = VersionRange . renderStyle style .
-#if MIN_VERSION_Cabal(3,0,0)
       D.pretty
-#else
-      D.disp
-#endif
       $ toPreCabal2VersionRange range
   where
     style = Style OneLineMode 0 0
