@@ -63,7 +63,6 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
       it "fails on unsupported spec-version" $ do
         [i|
         spec-version: 25.0
-        dependencies: foo == bar
         |] `shouldFailWith` ("The file package.yaml requires version 25.0 of the Hpack package specification, however this version of hpack only supports versions up to " ++ showVersion Hpack.version ++ ". Upgrading to the latest version of hpack may resolve this issue.")
 
       it "fails on unsupported spec-version from defaults" $ do
@@ -111,13 +110,13 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
     describe "github" $ do
       it "accepts owner/repo" $ do
         [i|
-        github: hspec/hspec
+        github: sol/hpack
         |] `shouldRenderTo` package [i|
-        homepage: https://github.com/hspec/hspec#readme
-        bug-reports: https://github.com/hspec/hspec/issues
+        homepage: https://github.com/sol/hpack#readme
+        bug-reports: https://github.com/sol/hpack/issues
         source-repository head
           type: git
-          location: https://github.com/hspec/hspec
+          location: https://github.com/sol/hpack
         |]
 
       it "accepts owner/repo/path" $ do
@@ -132,6 +131,11 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
           subdir: hspec-core
         |]
 
+      it "rejects URLs" $ do
+        [i|
+        github: https://github.com/sol/hpack/issues/365
+        |] `shouldFailWith` "package.yaml: Error while parsing $.github - expected owner/repo or owner/repo/subdir, but encountered \"https://github.com/sol/hpack/issues/365\""
+
     describe "homepage" $ do
       it "accepts homepage URL" $ do
         [i|
@@ -606,6 +610,15 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
             base
         |]
 
+      it "accepts dependencies with subcomponents" $ do
+        [i|
+        executable:
+          dependencies: foo:bar
+        |] `shouldRenderTo` (executable_ "foo" [i|
+        build-depends:
+            foo:bar
+        |]) {packageCabalVersion = "3.0"}
+
       it "accepts list of dependencies" $ do
         [i|
         executable:
@@ -1134,14 +1147,14 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
         internal-libraries:
           bar:
             source-dirs: src
-          |] `shouldRenderTo` internalLibrary "bar" [i|
-          exposed-modules:
-              Foo
-          other-modules:
-              Paths_foo
-          hs-source-dirs:
-              src
-          |]
+        |] `shouldRenderTo` internalLibrary "bar" [i|
+        exposed-modules:
+            Foo
+        other-modules:
+            Paths_foo
+        hs-source-dirs:
+            src
+        |]
 
       it "warns on unknown fields" $ do
         [i|
@@ -1159,6 +1172,17 @@ spec = around_ (inTempDirectoryNamed "foo") $ do
             source-dirs: src
         |] `shouldWarn` pure "Specified source-dir \"src\" does not exist"
 
+      it "accepts visibility" $ do
+        [i|
+        internal-libraries:
+          bar:
+            visibility: public
+        |] `shouldRenderTo` (internalLibrary "bar" [i|
+        visibility: public
+        other-modules:
+            Paths_foo
+        |]) {packageCabalVersion = "3.0"}
+
     describe "executables" $ do
       it "accepts arbitrary entry points as main" $ do
         touch "src/Foo.hs"
