@@ -7,11 +7,7 @@ import           Data.Maybe
 import           Data.String.Interpolate
 
 import           Distribution.Pretty (prettyShow)
-#if MIN_VERSION_Cabal(3,0,0)
 import           Distribution.Parsec (simpleParsec)
-#else
-import           Distribution.Parsec.Class (simpleParsec)
-#endif
 import qualified Distribution.License as Cabal
 
 import           Hpack.License
